jQuery(document).ready(() => {
  console.log("Tipzty is a live! 🔥 v1.2.2");

  checkCheckoutAndOrders();
});

const checkCheckoutAndOrders = () => {
  const isCheckoutPage =
    window.location.pathname.startsWith("/checkout") ||
    !!document.body.classList.contains("woocommerce-checkout");
  const isCheckoutOrderReceivedPage =
    window.location.pathname.startsWith("/checkout/order-received/") ||
    (!!document.body.classList.contains("woocommerce-checkout") &&
      !!document.body.classList.contains("woocommerce-order-received"));
  const search = window.location.search;
  const params = new URLSearchParams(search);
  const isFromTipztv = params.get("from") === "tipztv";

  let isValid = true;

  if (isCheckoutOrderReceivedPage) {
    console.log("✅ Checkout order received");

    const emailElement = document.querySelector(
      ".woocommerce-order-overview__email strong"
    );
    const totalAmountElement = document.querySelector(
      ".woocommerce-Price-amount bdi"
    );
    const orderNumberElement = document.querySelector(
      ".woocommerce-order-overview__order strong"
    );

    if (emailElement) {
      console.log("✅ Email:", emailElement.textContent);
    } else {
      console.log("🚫 Email:", emailElement);
      isValid = false;
    }

    if (totalAmountElement) {
      console.log("✅ Total Amount:", totalAmountElement.textContent);
    } else {
      console.log("🚫 Total Amount:", totalAmountElement);
      isValid = false;
    }

    if (orderNumberElement) {
      console.log("✅ Order number:", orderNumberElement.textContent);
    } else {
      console.log("🚫 Order number:", orderNumberElement);
      isValid = false;
    }

    if (isValid) {
      const totalAmount = parseFloat(
        totalAmountElement ? parseAmount(totalAmountElement.textContent) : 0
      );

      checkTransmissionSale({
        email: emailElement.textContent.trim(),
        total_amount: totalAmount,
      })
        .then(async (res) => {
          if (res.status === 200) {
            const json = await res.json();
            console.log("🕒 Checked sale, is already pending:", json.id);

            updateTransmissionSale(json.id, {
              transmission_id: json.transmission_id,
              order_number: orderNumberElement.textContent.trim(),
              status_url: window.location.href,
              status: true,
            }).then((res) => {
              if (res.status === 200) {
                console.log("✅ Sale updated successfully!");
              } else {
                console.log("🚫 Error updating the sale");
              }
            });
          } else {
            console.log("✅ This sale is already completed");
          }
        })
        .catch((error) => {
          console.log("🚫 Error checking the sale:", error.message);
        });
    }
  }

  if (isCheckoutPage && isFromTipztv) {
    const id = params.get("id");

    console.log("✅ Tipztv");
    console.log("✅ Checkout Page");
    console.log("✅ Transmission ID:", id);

    const form = document.querySelector("form.woocommerce-checkout");
    const totalAmountElement = document.querySelector(
      ".order-total .woocommerce-Price-amount bdi"
    );

    let totalAmount = 0;

    if (form) {
      console.log("✅ Form checkout:", form);
    } else {
      console.log("🚫 Form checkout:", form);
      isValid = false;
    }

    if (totalAmountElement) {
      console.log("✅ Total Amount:", totalAmountElement.textContent);
    } else {
      console.log("🚫 Total Amount:", totalAmountElement);
      isValid = false;
    }

    try {
      totalAmount = parseFloat(
        totalAmountElement ? parseAmount(totalAmountElement.textContent) : 0
      );

      if (Number.isNaN(totalAmount)) {
        console.log("🚫 Total Amount Format:", totalAmount);
        isValid = false;
      }

      if (!Number.isNaN(totalAmount) && totalAmount > 0) {
        console.log("✅ Total Amount Format:", totalAmount);
      }
    } catch (error) {
      console.log("🚫 Total Amount Format:", totalAmountElement.textContent);
      isValid = false;
    }

    form.addEventListener("submit", (e) => {
      e.preventDefault();

      const emailInput = document.querySelector("input[type=email]");
      const firstNameInput = document.querySelector(
        "input[name=billing_first_name]"
      );
      const lastNameInput = document.querySelector(
        "input[name=billing_last_name]"
      );
      const email = emailInput.value;
      const firstName = firstNameInput.value;
      const lastName = lastNameInput.value;
      const fullName = `${firstName} ${lastName}`;

      if (email && email !== "") {
        console.log("✅ Email:", email);
      } else {
        console.log("🚫 Email: empty");
        isValid = false;
      }

      if (firstName && firstName !== "") {
        console.log("✅ FullName:", firstName);
      } else {
        console.log("🚫 FullName: empty");
        isValid = false;
      }

      if (isValid) {
        createTransmissionSale({
          checkout_id: 0,
          transmission_id: parseInt(id),
          total_amount: totalAmount,
          full_name: fullName,
          email: email,
          order_number: "",
          status: false,
          status_url: "",
        });
      }
    });
  }
};

const activeHomeWidget = () => {};

const createTransmissionSale = (data) => {
  return fetch("https://go.tipzty.com/transmissionsales", {
    method: "POST",
    body: JSON.stringify(data),
    headers: {
      "Content-Type": "application/json",
    },
  });
};

const updateTransmissionSale = (id, data) => {
  return fetch("https://go.tipzty.com/transmissionsales/" + id, {
    method: "PUT",
    body: JSON.stringify(data),
    headers: {
      "Content-Type": "application/json",
    },
  });
};

const checkTransmissionSale = (data) => {
  return fetch("https://api.tipzty.com/api/check-transmission-sale", {
    method: "POST",
    body: JSON.stringify(data),
    headers: {
      "Content-Type": "application/json",
    },
  });
};

const parseAmount = (amount) => {
  return parseInt(
    amount.replace("$", "").replace(/\,/g, "").replace(/\./g, "").trim()
  );
};

function toggleWidget(isHome) {
  var parentClass = isHome ? ".t-home-widget" : ".t-widget";
  var review = document.querySelector(`${parentClass} .t-review`);
  var iframe = document.querySelector(`${parentClass} .t-iframe`);
  var btn = document.querySelector(`${parentClass} .t-logo`);

  if (review.style.visibility == "visible") {
    review.style.visibility = "hidden";
    btn.src = btn.src.replace("close.png", "btn.png");
    btn.classList.add("animate");
  } else {
    const src = localStorage.getItem("@iframe_tipzty");

    if (iframe.src !== src) {
      iframe.src = src;
    }

    review.style.visibility = "visible";
    btn.src = btn.src.replace("btn.png", "close.png");
    btn.classList.remove("animate");
  }
}

async function newProduct(token, prod, urlImage) {
  var urlProduct = window.location.href;
  var cant = 0;

  if (prod.stock_quantity != null) {
    cant = prod.stock_quantity;
  }

  var body = {
    shop_id: prod.id,
    name: prod.name,
    description: prod.description,
    short_description: prod.short_description,
    price: parseInt(prod.price),
    discount: parseInt(prod.sale_price),
    stock: cant,
    avatar: urlImage,
    url_storage: urlProduct,
  };

  await fetch("https://go.tipzty.com/api/products", {
    method: "POST",
    body: JSON.stringify(body),
    headers: {
      "X-Tipzty-Key": token,
      "content-type": "application/json",
    },
  }).then((resp) => {
    console.log("product created:", resp.json());
  });
}

const parseBrandName = (branName) => {
  return branName.replace(/ /g, "").toLowerCase().trim();
};
